@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2025 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2026 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -568,6 +568,8 @@ class MainWindow : public QMainWindow {
 
     void on_actionFind_action_triggered();
 
+    void on_actionRedo_action_triggered();
+
     void releaseDockWidgetSizes();
 
     void on_actionInsert_table_triggered();
@@ -881,6 +883,7 @@ class MainWindow : public QMainWindow {
     bool _isMaximizedBeforeFullScreen = false;
     bool _isMinimizedBeforeFullScreen = false;
     WaitingSpinnerWidget *_openAiActivitySpinner = nullptr;
+    QAction *_lastTriggeredAction = nullptr;
 
     void initializeOpenAiActivitySpinner();
 
@@ -1134,7 +1137,8 @@ class MainWindow : public QMainWindow {
 
     void initFakeVim(QOwnNotesMarkdownTextEdit *noteTextEdit);
 
-    void openNotesContextMenu(const QPoint globalPos, bool multiNoteMenuEntriesOnly = false);
+    void openNotesContextMenu(const QPoint globalPos, bool hasNotes = true,
+                              bool hasFolders = false);
 
     void updateCurrentNoteTextHash();
 
