@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2025 Patrizio Bekerle -- <patrizio@bekerle.com>
+ * Copyright (c) 2014-2026 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1160,6 +1160,13 @@ QIcon Utils::Gui::noteIcon() {
     return s_noteIcon;
 }
 
+QIcon Utils::Gui::favoriteNoteIcon() {
+    static const QIcon s_favoriteNoteIcon = QIcon::fromTheme(
+        QStringLiteral("favorite-favorited"),
+        QIcon(QStringLiteral(":/icons/breeze-qownnotes/16x16/favorite-favorited.svg")));
+    return s_favoriteNoteIcon;
+}
+
 QIcon Utils::Gui::tagIcon() {
     static const QIcon s_tagIcon = QIcon::fromTheme(
         QStringLiteral("tag"), QIcon(QStringLiteral(":/icons/breeze-qownnotes/16x16/tag.svg")));
